@@ -14,7 +14,7 @@ sub get_nginx_cfg ($self) {
 
 sub return_static ( $self, $req ) {
     if ( $req->{path_tail} && $req->{path_tail}->is_file ) {
-        if ( my $path = $ENV->share->get( $req->{path} . $req->{path_tail}, storage => 'www' ) ) {
+        if ( my $path = $ENV->{share}->get( 'www', $req->{path} . $req->{path_tail} ) ) {
             my $data = P->file->read_bin($path);
 
             $path = P->path($path);
